@@ -2,7 +2,7 @@
 # Routines (part of main program) for dealing with DATA.
 #
 # This file is part of SAUCE, a very picky anti-spam receiver-SMTP.
-# SAUCE is Copyright (C) 1997-2001 Ian Jackson
+# SAUCE is Copyright (C) 1997-2003 Ian Jackson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 #
-# $Id: msgdata.tcl,v 1.35 2001/03/21 23:53:14 ian Exp $
+# $Id: msgdata.tcl,v 1.40 2003/06/15 15:46:40 ian Exp $
 
 # While receiving the message data, we are either:
 # * Receiving the header:
@@ -61,7 +61,7 @@
 #  normal + bait + lax     Ignore   Blacklist     Discard  550
 
 thread_subproc ic a_kind {kind} {
-    return [expr {[lsearch -exact $kind $state(a_kinds)] >= 0}]
+    return [expr {[lsearch -exact $state(a_kinds) $kind] >= 0}]
 }
 
 thread_subproc ic rej_bl {what inwhere} {
@@ -113,12 +113,12 @@ thread_chainproc ic hdr_read {data} {
 	}
     } elseif {[regexp {^([\041-\071\073-\176\241-\376]+)[ \t]*:} \
 	              $data all newhn]} {
-	ic_hdr_process1 $state(currenthn) $state(currenthl)
+	ic_hdr_process1 $eom $state(currenthn) $state(currenthl)
 	set state(currenthn) $newhn
 	set state(currenthl) $data
     } elseif {$eom || ![string length $data]} {
 	# End of headers
-	ic_hdr_process1 $state(currenthn) $state(currenthl)
+	ic_hdr_process1 $eom $state(currenthn) $state(currenthl)
 	set state(currenthn) {}
 	set state(currenthl) {}
 	if {!$eom} { append state(header) "$data\n" }
@@ -127,7 +127,7 @@ thread_chainproc ic hdr_read {data} {
 	} elseif {$require_messageid && ![info exists state(mid)]} {
 	    ic_rej "No Message-ID header"
 	} elseif {$require_messageid &&
-		  [info exists state(resentany)] &&
+		  $state(resentany) &&
 		  ![llength $state(resentmids)]} {
 	    ic_rej "Resent- header(s), but no Resent-Message-ID"
 	}
@@ -155,10 +155,10 @@ thread_subproc ic msg_checkeof {} {
     }
 }
 
-thread_subproc ic hdr_process1 {hn hl} {
+thread_subproc ic hdr_process1 {eom hn hl} {
     global blacklist_message max_header_size errorInfo header_reject_res
     global errorCode errorInfo
-    debug 3 "hdr_process1 >$hn|$hl<"
+    debug 3 "hdr_process1 >$eom|$hn|$hl<"
     if {![string length $hn]} return
     append state(header) "$hl\n"
     set lowerhn [string tolower $hn]
@@ -186,7 +186,7 @@ thread_subproc ic hdr_process1 {hn hl} {
     }
     if {[regexp -nocase {^(resent-)?(from|sender|reply-to)$} $hn]} {
 	if {[catch {
-	    ic_hdr_recipients $hn $hl
+	    ic_hdr_recipients $eom $hn $hl
 	} emsg]} {
 	    if {"$errorCode" == "SAUCE BADHDR"} {
 		debug 3 "header error >$emsg|$errorInfo<"
@@ -212,9 +212,9 @@ thread_subproc ic hdr_process1 {hn hl} {
 
 thread_subproc ic hdr_err {emsg} { error $emsg {} {SAUCE BADHDR} }
 
-thread_subproc ic hdr_recipients {hn tf} {
+thread_subproc ic hdr_recipients {eom hn tf} {
     set lowerhn [string tolower $hn]
-    debug 3 "hdr_recipients >$hn|$tf<"
+    debug 3 "hdr_recipients >$eom|$hn|$tf<"
     set colev 0
     set uq {}
     while {[string length $tf]} {
@@ -259,9 +259,9 @@ thread_subproc ic hdr_recipients {hn tf} {
 	} elseif {[regexp {^[0-9a-f.]*<([][0-9a-f.@]+)>,(.*)} \
 		          $uq all ras uq]} {
 	    regsub {^(@[][0-9a-f.]:)*} $ras {} ras
-	    ic_hdr_1recipient $hn $ras
+	    ic_hdr_1recipient $eom $hn $ras
 	} elseif {[regexp {^([][0-9a-f.@]+),(.*)} $uq all ras uq]} {
-	    ic_hdr_1recipient $hn $ras
+	    ic_hdr_1recipient $eom $hn $ras
 	} elseif {[regexp {^,(.*)} $uq all uq]} {
 	} else {
 	    ic_hdr_err "syntax error"
@@ -269,13 +269,17 @@ thread_subproc ic hdr_recipients {hn tf} {
     }
 }
 
-thread_subproc ic hdr_1recipient {hn ras} {
-    debug 3 "hdr_1recipient >$hn|$ras<"
+thread_subproc ic hdr_1recipient {eom hn ras} {
+    debug 3 "hdr_1recipient >$eom|$hn|$ras<"
     if {![regexp {^([0-9a-f.]+)@([][0-9a-f.]+)$} $ras all lp dm]} {
 	ic_hdr_err "invalid address"
     }
-    regsub -all {\.} $lp 2e lp
-    regsub -all {\.} $dm 2e dm
+    foreach from {. [ ]} {
+	foreach var {lp dm} {
+	    binary scan $from H* to
+	    regsub -all \\$from [set $var] $to $var
+	}
+    }
     set lp [binary format H* $lp]
     set dm [binary format H* $dm]
 
@@ -287,7 +291,7 @@ thread_subproc ic hdr_1recipient {hn ras} {
     if {"[ds_get addr-list $addr]" == "black"} {
 	ic_rej_bl $addr $hn
     }
-    ic_msg_maincontrol X
+    ic_msg_maincontrol $eom
 }
 
 thread_subproc ic hdr_endhdrs {eom} {
@@ -325,7 +329,7 @@ thread_subproc ic msg_maincontrol {eom} {
 	manyset [lindex $state(originators_tochk) 0] lp dm hn
 	set addr $lp@$dm
 	set state(originators_tochk) [lreplace $state(originators_tochk) 0 0]
-	if {![llength state(rej_msg)]} {
+	if {![llength $state(rej_msg)]} {
 	    switch -exact -- [ds_get addr-list $addr] {
 		white - whitesoon {
 		}
@@ -411,12 +415,12 @@ thread_chainproc ic body_data_ok {eom rejwarnings data} {
 	}
     }
     if {$add_received} {
-	regsub {^.Name\: } {$Name: debian_version_0_7_7 $} {} rcsinfo
+	regsub {^.Name\: } {$Name: debian_version_0_7_14 $} {} rcsinfo
 	if {![regexp {^[ $]*$} $rcsinfo]} {
 	    regsub {^debian_version_} $rcsinfo v rcsinfo
 	    regsub -all _ $rcsinfo . rcsinfo
 	} else {
-	    regsub {^.Revision\: } {$Revision: 1.35 $} r rcsinfo
+	    regsub {^.Revision\: } {$Revision: 1.40 $} r rcsinfo
 	}
 	regsub {[ $]*$} $rcsinfo {} rcsinfo
 	set date [date_822]
@@ -588,7 +592,7 @@ thread_subproc ic blacklist_thing {sa value tellwho valdesc} {
 	}
 	black {
 	    log notice "$cd ... $sa $value ... refreshing blacklist"
-	    setstate addr $value $add_bl black $bl_to
+	    setstate $sa $value $add_bl black $bl_to
 	    return 1
 	}
 	white {
