@@ -2,7 +2,7 @@
 # Code for notifying people that they have been blacklisted.
 #
 # This file is part of SAUCE, a very picky anti-spam receiver-SMTP.
-# SAUCE is Copyright (C) 1997-2001 Ian Jackson
+# SAUCE is Copyright (C) 1997-2003 Ian Jackson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 #
-# $Id: notifybl.tcl,v 1.9 2001/03/21 23:53:14 ian Exp $
+# $Id: notifybl.tcl,v 1.11 2003/06/15 15:46:40 ian Exp $
 
 ########## notifybl threads
 #
@@ -37,7 +37,8 @@
 thread_typedefine notifybl {notifyaddr whatbl why} {
     global notifybl_timeout
     debug 1 [list notifybl $notifyaddr $whatbl $why]
-    if {![regexp -nocase {^(.+)\@([-.0-9a-z]+)$} $notifyaddr all lp state(dm)]} {
+    if {![regexp -nocase {^(.+)\@([.0-9a-z\-\[\]]+)$} \
+                 $notifyaddr all lp state(dm)]} {
 	error "trying to notify address $notifyaddr"
     }
     set state(lp) [lp_quote $lp]
