@@ -2,7 +2,7 @@
 # Config variables for SAUCE and their defaults.
 #
 # This file is part of SAUCE, a very picky anti-spam receiver-SMTP.
-# SAUCE is Copyright (C) 1997-2001 Ian Jackson
+# SAUCE is Copyright (C) 1997-2003 Ian Jackson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 #
-# $Id: sconfig.tcl,v 1.34 2001/03/21 23:53:15 ian Exp $
+# $Id: sconfig.tcl,v 1.38 2003/06/15 15:46:40 ian Exp $
 
 
 set @@@var_dir@@@ .
@@ -32,14 +32,15 @@ config_var remote_port                smtp  port
 				     
 config_var always_blacklist_site     false  boolean
 config_var blacklist_all_addresses   false  boolean
+config_var blacklist_on_bounces      false  boolean
 
 config_var conns_max                 120    number	     1  10000
 
 config_var ident_timeout              60s   units interval   0ms    5m
 config_var fail_send_timeout           1s   units interval   0ms    5m
 config_var command_timeout             5m   units interval   0ms    1h
-config_var verify_perconn_timeout      2m   units interval   0ms    5m
-config_var verify_all_timeout          6m   units interval   0ms   15m
+config_var verify_perconn_timeout    130s   units interval   0ms    5m
+config_var verify_all_timeout        270s   units interval   0ms   15m
 config_var dns_timeout                45s   units interval 500ms    5m
 config_var verify_cache_timeout       60s   units interval   0ms    7d
 config_var verify_reuse_timeout        4m   units interval   0ms    1h
@@ -91,6 +92,7 @@ config_var ipaddr_phase_offset         0    number           0   255
 
 config_var mixedkinds_message  "Mixed recipient kinds, try this one later"      printable
 config_var bland_message       "Recipient verified"                             printable
+config_var bouncedjunk_message "Bounce of probably-forged junk mail"            printable
 config_var blacklist_message   "You are blacklisted - contact postmaster."      printable
 config_var blacknone_message   "Message blacklisted - contact postmaster."      printable
 config_var blacksite_message   "Your site is blacklisted - contact postmaster." printable
