@@ -3,7 +3,7 @@
 # Main SMTP protocol implementation
 #
 # This file is part of SAUCE, a very picky anti-spam receiver-SMTP.
-# SAUCE is Copyright (C) 1997-2001 Ian Jackson
+# SAUCE is Copyright (C) 1997-2003 Ian Jackson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 #
-# $Id: smtp.tcl,v 1.6 2001/03/21 23:53:15 ian Exp $
+# $Id: smtp.tcl,v 1.14 2003/06/15 15:46:40 ian Exp $
 
 
 ########## connection threads
@@ -128,14 +128,11 @@ thread_typedefine ic {chan lalhlp ra rp} {
     set state(smtperrors) 0
     set state(rcptcounter) 0
 
-    set state(rej_msg) {}
-    set state(defer_msg) {}
-    set state(delay_msg) {}
-    set state(att_rcpts) {}
     set state(rbl_hits) {}
-
     set state(rblids) {}
-    set state(resentmids) {}
+
+    ic_msg_resetvars
+
     set state(dnsptrid) \
 	    [thread_start dnsptr "$state(desc) / reverse lookup" $ra]
     if {[catch {
@@ -447,6 +444,7 @@ thread_subproc ic commandfinalresponse {evtype message} {
 }
 
 thread_chainproc ic mtaquit_done {evtype message args} {
+    fconfigure $state(mtachan) -blocking true
     catch_close_cleardesc state(mtachan)
     ic_commandresponse_maybefinal $evtype 1 $message
 }
@@ -490,6 +488,7 @@ thread_chainproc ic command_ok {cmd} {
     global canonical_hostname blacklist_message bland_message
     global admin_chal_timeout always_blacklist_site
     global adminsecret blacksite_message allow_saucestate mixedkinds_message
+    global blacklist_on_bounces bouncedjunk_message
     after cancel $state(itoid)
     unset state(itoid)
     regexp {^.*} $cmd cmd
@@ -630,6 +629,12 @@ thread_chainproc ic command_ok {cmd} {
 				[concat $state(defer_conn) $state(defer_msg)]
 			switch -exact $atype {
 			    bait {
+				if {!$blacklist_on_bounces &&
+			            ![string length $state(mf_dm)]} {
+				    ic_commandresponse major \
+					    "550 $bouncedjunk_message"
+				    return
+				}
 				lappend state(add_bl) \
 					"Sent mail to bait address $lp@$dm"
 				if {$always_blacklist_site} ic_blacklist_site
@@ -724,7 +729,7 @@ thread_chainproc ic command_ok {cmd} {
 	    }
 	    saucestate {
 		if {$allow_saucestate} {
-		    set op "100-\n"
+		    set op "100-$id\n"
 		    foreach x [lsort [array names state]] {
 			append op "100-[list $x $state($x)]\n"
 		    }
@@ -788,7 +793,7 @@ thread_subproc ic helo {helocmd smtpstyle rhs} {
 	} elseif {"[ds_get site-list $state(ra)]" == "white"} {
 	    ic_set_maildomain "\[$state(ra)\]" $rhs
 	} else {
-	    set state(dnsid) [thread_start dns "$state(desc) / HELO lookup" $rhs A 1]
+	    set state(dnsid) [thread_start dns "$state(desc) / HELO lookup" $rhs A 0]
 	    thread_join ic $id dns $state(dnsid) helodns_ok helodns_err $rhs
 	}
     }
@@ -842,7 +847,7 @@ thread_subproc ic findmore_maildomain {chstart chnow hs} {
 	ic_set_maildomain $chstart $hs
     } else {
 	set state(dnsid) [thread_start dns "$state(desc) / maildomain lookup" \
-	                  $chnow MX 0]
+	                  $chnow MX 1]
 	thread_join ic $id dns $state(dnsid) fch_ok fch_err $chstart $chnow $hs
     }
 }
@@ -901,7 +906,7 @@ thread_subproc ic mta_greethelo_err {emsg} {
     global canonical_hostname
     
     regsub -nocase {^[0-9]* ?[-+.:0-9a-z]* *} $emsg {} emsg
-    ic_commandfinalresponse major "421 $canonical_hostname $emsg"
+    ic_commandfinalresponse major "421 $canonical_hostname MTA $emsg"
 }
 
 thread_chainproc ic mta_helo_ok {data} {
