@@ -2,7 +2,7 @@
 # `Thread'-handling functions
 #
 # This file is part of SAUCE, a very picky anti-spam receiver-SMTP.
-# SAUCE is Copyright (C) 1997-2001 Ian Jackson
+# SAUCE is Copyright (C) 1997-2003 Ian Jackson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 #
-# $Id: thread.tcl,v 1.20 2001/03/21 23:53:15 ian Exp $
+# $Id: thread.tcl,v 1.22 2003/06/15 15:46:40 ian Exp $
 
 proc thrdbg_threads {type} {
     foreach x [lsort [info globals]] {
@@ -232,7 +232,7 @@ proc thread_after {type id timeout func args} {
 
 proc bgerror {msg} {
     global errorCode errorInfo
-    log error "sauce: untrapped error: $msg ($errorCode $errorInfo)"
+    log error "thread: untrapped error: $msg ($errorCode $errorInfo)"
 }
 
 ########## threadio functions
